/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.runtime;

import java.io.Serializable;
import java.util.Date;

import org.ow2.bonita.facade.uuid.ActivityBodyUUID;

/**
 * Runtime (recorded) data concerning activities is divided in a common part and a body.<br>
 * This interface concerns the body of the activity.<br>
 * It provides three common methods for the four interfaces dedicated for body of activity<br>
 * (getting ActivityBodyUUID, started and ended date).
 *
 */
public interface ActivityBody extends Serializable {

  /**
   * Return the UUID of the ActivityBody.<br>
   * For instance, if the body of the activity is a TaskInstance this UUID is a TaskUUID.
   * @return The UUID of the ActivityBody.
   */
  ActivityBodyUUID getUUID();

  ActivityBody copy();

  /**
   * Returns the date recorded after the activity is started.
   * @return The date recorded after the activity is started.
   */
  Date getStartedDate();

  /**
   * Returns the date recorded after the activity is finished.
   * @return The date recorded after the activity is finished.
   */
  Date getEndedDate();

}


